==> wawa-service-api-0.0.8-20171031.130549-2-sources.jar: cn/com/wawa/service/api/dto/WawaCatcherSimpleDto.java <==
package cn.com.wawa.service.api.dto;

import java.io.Serializable;

/**
 * Created by gyf .
 * 2017/10/31 .
 */
public class WawaCatcherSimpleDto implements Serializable {

    private static final long serialVersionUID = -481775249861126389L;

    /**
     * 娃娃机id
     */
    private Long id;

    /**
     * 娃娃id
     */
    private Long wawaId;

    /**
     * 主盒子mac
     */
    private String mac1;

    /**
     * 副盒子mac
     */
    private String mac2;

    /**
     * 摄像头一号
     */
    private String camera1;

    /**
     * 摄像头二号
     */
    private String camera2;

    /**
     * 娃娃机编号
     */
    private Integer catcherNum;

    /**
     * 房间编号
     */
    private String roomId;

    /**
     * 娃娃机名称
     */
    private String catcherName;

    /**
     * 娃娃机排序值
     */
    private Long payload;

    /**
     * 娃娃总数
     */
    private Integer totality;

    /**
     * 娃娃剩余数量
     */
    private Integer stock;

    /**
     * 娃娃图
     */
    private String indexImage;

    /**
     * 娃娃名称
     */
    private String wawaName;

    /**
     * 娃娃的价格
     */
    private Long wawaPrice;

    public Long getId() {
        return id;
    }

    public void setId(Long id) {
        this.id = id;
    }

    public Long getWawaId() {
        return wawaId;
    }

    public void setWawaId(Long wawaId) {
        this.wawaId = wawaId;
    }

    public String getMac1() {
        return mac1;
    }

    public void setMac1(String mac1) {
        this.mac1 = mac1;
    }

    public String getMac2() {
        return mac2;
    }

    public void setMac2(String mac2) {
        this.mac2 = mac2;
    }

    public String getCamera1() {
        return camera1;
    }

    public void setCamera1(String camera1) {
        this.camera1 = camera1;
    }

    public String getCamera2() {
        return camera2;
    }

    public void setCamera2(String camera2) {
        this.camera2 = camera2;
    }

    public Integer getCatcherNum() {
        return catcherNum;
    }

    public void setCatcherNum(Integer catcherNum) {
        this.catcherNum = catcherNum;
    }

    public String getRoomId() {
        return roomId;
    }

    public void setRoomId(String roomId) {
        this.roomId = roomId;
    }

    public String getCatcherName() {
        return catcherName;
    }

    public void setCatcherName(String catcherName) {
        this.catcherName = catcherName;
    }

    public Long getWawaPrice() {
        return wawaPrice;
    }

    public void setWawaPrice(Long wawaPrice) {
        this.wawaPrice = wawaPrice;
    }

    public Long getPayload() {
        return payload;
    }

    public void setPayload(Long payload) {
        this.payload = payload;
    }

    public Integer getTotality() {
        return totality;
    }

    public void setTotality(Integer totality) {
        this.totality = totality;
    }

    public Integer getStock() {
        return stock;
    }

    public void setStock(Integer stock) {
        this.stock = stock;
    }

    public String getIndexImage() {
        return indexImage;
    }

    public void setIndexImage(String indexImage) {
        this.indexImage = indexImage;
    }

    public String getWawaName() {
        return wawaName;
    }

    public void setWawaName(String wawaName) {
        this.wawaName = wawaName;
    }
}

==> wawa-service-api-0.0.14-20171201.121618-1-sources.jar: cn/com/wawa/service/api/dto/WawaCatcherSimpleDto.java <==
package cn.com.wawa.service.api.dto;

import java.io.Serializable;

/**
 * Created by gyf . 2017/10/31 .
 */
public class WawaCatcherSimpleDto implements Serializable {

    private static final long serialVersionUID = -481775249861126389L;

    /**
     * 娃娃机id
     */
    private Long              id;

    /**
     * 娃娃id
     */
    private Long              wawaId;

    /**
     * 主盒子mac
     */
    private String            mac1;

    /**
     * 副盒子mac
     */
    private String            mac2;

    /**
     * 摄像头一号
     */
    private String            camera1;

    /**
     * 摄像头二号
     */
    private String            camera2;

    /**
     * 娃娃机编号
     */
    private Integer           catcherNum;

    /**
     * 房间编号
     */
    private String            roomId;

    /**
     * 娃娃机名称
     */
    private String            catcherName;

    /**
     * 娃娃机排序值
     */
    private Long              payload;

    /**
     * 娃娃总数
     */
    private Integer           totality;

    /**
     * 娃娃剩余数量
     */
    private Integer           stock;

    /**
     * 娃娃图
     */
    private String            indexImage;

    /**
     * 娃娃名称
     */
    private String            wawaName;

    /**
     * 娃娃的价格
     */
    private Long              wawaPrice;

    /**
     * 娃娃机版本号
     */
    private String            catcherVersion;

    public Long getId() {
        return id;
    }

    public void setId(Long id) {
        this.id = id;
    }

    public Long getWawaId() {
        return wawaId;
    }

    public void setWawaId(Long wawaId) {
        this.wawaId = wawaId;
    }

    public String getMac1() {
        return mac1;
    }

    public void setMac1(String mac1) {
        this.mac1 = mac1;
    }

    public String getMac2() {
        return mac2;
    }

    public void setMac2(String mac2) {
        this.mac2 = mac2;
    }

    public String getCamera1() {
        return camera1;
    }

    public void setCamera1(String camera1) {
        this.camera1 = camera1;
    }

    public String getCamera2() {
        return camera2;
    }

    public void setCamera2(String camera2) {
        this.camera2 = camera2;
    }

    public Integer getCatcherNum() {
        return catcherNum;
    }

    public void setCatcherNum(Integer catcherNum) {
        this.catcherNum = catcherNum;
    }

    public String getRoomId() {
        return roomId;
    }

    public void setRoomId(String roomId) {
        this.roomId = roomId;
    }

    public String getCatcherName() {
        return catcherName;
    }

    public void setCatcherName(String catcherName) {
        this.catcherName = catcherName;
    }

    public Long getWawaPrice() {
        return wawaPrice;
    }

    public void setWawaPrice(Long wawaPrice) {
        this.wawaPrice = wawaPrice;
    }

    public Long getPayload() {
        return payload;
    }

    public void setPayload(Long payload) {
        this.payload = payload;
    }

    public Integer getTotality() {
        return totality;
    }

    public void setTotality(Integer totality) {
        this.totality = totality;
    }

    public Integer getStock() {
        return stock;
    }

    public void setStock(Integer stock) {
        this.stock = stock;
    }

    public String getIndexImage() {
        return indexImage;
    }

    public void setIndexImage(String indexImage) {
        this.indexImage = indexImage;
    }

    public String getWawaName() {
        return wawaName;
    }

    public void setWawaName(String wawaName) {
        this.wawaName = wawaName;
    }

    /**
     * catcherVersion.
     *
     * @return the catcherVersion
     */
    public String getCatcherVersion() {
        return catcherVersion;
    }

    /**
     * catcherVersion.
     *
     * @param catcherVersion the catcherVersion to set
     */
    public void setCatcherVersion(String catcherVersion) {
        this.catcherVersion = catcherVersion;
    }

}
